pub enum CoreAllocation {
OsDefault,
PinnedCores {
min: usize,
max: usize,
},
DedicatedCoreSet {
min: usize,
max: usize,
},
}This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Variants
OsDefault
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Use OS default allocation (i.e. do not alter core affinity)
PinnedCores
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Pin each thread to a core in given range. Number of cores should be >= number of threads
Fields
DedicatedCoreSet
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Pin the threads to a set of cores
Implementations
Sourceimpl CoreAllocation
impl CoreAllocation
Sourcepub fn as_core_mask_vector(&self) -> Vec<usize>
๐Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
pub fn as_core_mask_vector(&self) -> Vec<usize>
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Converts into a vector of core IDs. OsDefault is converted to vector with all core IDs.