pub struct ThreadManagerConfig {
pub native_configs: HashMap<String, NativeConfig>,
pub native_runtime_mapping: HashMap<String, String>,
pub rayon_configs: HashMap<String, RayonConfig>,
pub rayon_runtime_mapping: HashMap<String, String>,
pub tokio_configs: HashMap<String, TokioConfig>,
pub tokio_runtime_mapping: HashMap<String, String>,
pub default_core_allocation: CoreAllocation,
}This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Fields
native_configs: HashMap<String, NativeConfig>This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
native_runtime_mapping: HashMap<String, String>This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
rayon_configs: HashMap<String, RayonConfig>This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
rayon_runtime_mapping: HashMap<String, String>This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
tokio_configs: HashMap<String, TokioConfig>This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
tokio_runtime_mapping: HashMap<String, String>This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
default_core_allocation: CoreAllocationThis crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.